# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class ApiCertificate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'expires_on': 'int',
        'fingerprint': 'str',
        'id': 'str',
        'issued_on': 'int',
        'issuer_common_name': 'str',
        'issuer_organization': 'str',
        'issuer_organizational_unit': 'str',
        'pem': 'str',
        'serial_number': 'str',
        'subject_common_name': 'str',
        'subject_organization': 'str',
        'subject_organizational_unit': 'str'
    }

    attribute_map = {
        'expires_on': 'expiresOn',
        'fingerprint': 'fingerprint',
        'id': 'id',
        'issued_on': 'issuedOn',
        'issuer_common_name': 'issuerCommonName',
        'issuer_organization': 'issuerOrganization',
        'issuer_organizational_unit': 'issuerOrganizationalUnit',
        'pem': 'pem',
        'serial_number': 'serialNumber',
        'subject_common_name': 'subjectCommonName',
        'subject_organization': 'subjectOrganization',
        'subject_organizational_unit': 'subjectOrganizationalUnit'
    }

    def __init__(self, expires_on=None, fingerprint=None, id=None, issued_on=None, issuer_common_name=None, issuer_organization=None, issuer_organizational_unit=None, pem=None, serial_number=None, subject_common_name=None, subject_organization=None, subject_organizational_unit=None, local_vars_configuration=None):  # noqa: E501
        """ApiCertificate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._expires_on = None
        self._fingerprint = None
        self._id = None
        self._issued_on = None
        self._issuer_common_name = None
        self._issuer_organization = None
        self._issuer_organizational_unit = None
        self._pem = None
        self._serial_number = None
        self._subject_common_name = None
        self._subject_organization = None
        self._subject_organizational_unit = None
        self.discriminator = None

        if expires_on is not None:
            self.expires_on = expires_on
        if fingerprint is not None:
            self.fingerprint = fingerprint
        if id is not None:
            self.id = id
        if issued_on is not None:
            self.issued_on = issued_on
        if issuer_common_name is not None:
            self.issuer_common_name = issuer_common_name
        if issuer_organization is not None:
            self.issuer_organization = issuer_organization
        if issuer_organizational_unit is not None:
            self.issuer_organizational_unit = issuer_organizational_unit
        if pem is not None:
            self.pem = pem
        if serial_number is not None:
            self.serial_number = serial_number
        if subject_common_name is not None:
            self.subject_common_name = subject_common_name
        if subject_organization is not None:
            self.subject_organization = subject_organization
        if subject_organizational_unit is not None:
            self.subject_organizational_unit = subject_organizational_unit

    @property
    def expires_on(self):
        """Gets the expires_on of this ApiCertificate.  # noqa: E501


        :return: The expires_on of this ApiCertificate.  # noqa: E501
        :rtype: int
        """
        return self._expires_on

    @expires_on.setter
    def expires_on(self, expires_on):
        """Sets the expires_on of this ApiCertificate.


        :param expires_on: The expires_on of this ApiCertificate.  # noqa: E501
        :type: int
        """

        self._expires_on = expires_on

    @property
    def fingerprint(self):
        """Gets the fingerprint of this ApiCertificate.  # noqa: E501


        :return: The fingerprint of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this ApiCertificate.


        :param fingerprint: The fingerprint of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._fingerprint = fingerprint

    @property
    def id(self):
        """Gets the id of this ApiCertificate.  # noqa: E501


        :return: The id of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ApiCertificate.


        :param id: The id of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def issued_on(self):
        """Gets the issued_on of this ApiCertificate.  # noqa: E501


        :return: The issued_on of this ApiCertificate.  # noqa: E501
        :rtype: int
        """
        return self._issued_on

    @issued_on.setter
    def issued_on(self, issued_on):
        """Sets the issued_on of this ApiCertificate.


        :param issued_on: The issued_on of this ApiCertificate.  # noqa: E501
        :type: int
        """

        self._issued_on = issued_on

    @property
    def issuer_common_name(self):
        """Gets the issuer_common_name of this ApiCertificate.  # noqa: E501


        :return: The issuer_common_name of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._issuer_common_name

    @issuer_common_name.setter
    def issuer_common_name(self, issuer_common_name):
        """Sets the issuer_common_name of this ApiCertificate.


        :param issuer_common_name: The issuer_common_name of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._issuer_common_name = issuer_common_name

    @property
    def issuer_organization(self):
        """Gets the issuer_organization of this ApiCertificate.  # noqa: E501


        :return: The issuer_organization of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._issuer_organization

    @issuer_organization.setter
    def issuer_organization(self, issuer_organization):
        """Sets the issuer_organization of this ApiCertificate.


        :param issuer_organization: The issuer_organization of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._issuer_organization = issuer_organization

    @property
    def issuer_organizational_unit(self):
        """Gets the issuer_organizational_unit of this ApiCertificate.  # noqa: E501


        :return: The issuer_organizational_unit of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._issuer_organizational_unit

    @issuer_organizational_unit.setter
    def issuer_organizational_unit(self, issuer_organizational_unit):
        """Sets the issuer_organizational_unit of this ApiCertificate.


        :param issuer_organizational_unit: The issuer_organizational_unit of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._issuer_organizational_unit = issuer_organizational_unit

    @property
    def pem(self):
        """Gets the pem of this ApiCertificate.  # noqa: E501


        :return: The pem of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._pem

    @pem.setter
    def pem(self, pem):
        """Sets the pem of this ApiCertificate.


        :param pem: The pem of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._pem = pem

    @property
    def serial_number(self):
        """Gets the serial_number of this ApiCertificate.  # noqa: E501


        :return: The serial_number of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this ApiCertificate.


        :param serial_number: The serial_number of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._serial_number = serial_number

    @property
    def subject_common_name(self):
        """Gets the subject_common_name of this ApiCertificate.  # noqa: E501


        :return: The subject_common_name of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._subject_common_name

    @subject_common_name.setter
    def subject_common_name(self, subject_common_name):
        """Sets the subject_common_name of this ApiCertificate.


        :param subject_common_name: The subject_common_name of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._subject_common_name = subject_common_name

    @property
    def subject_organization(self):
        """Gets the subject_organization of this ApiCertificate.  # noqa: E501


        :return: The subject_organization of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._subject_organization

    @subject_organization.setter
    def subject_organization(self, subject_organization):
        """Sets the subject_organization of this ApiCertificate.


        :param subject_organization: The subject_organization of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._subject_organization = subject_organization

    @property
    def subject_organizational_unit(self):
        """Gets the subject_organizational_unit of this ApiCertificate.  # noqa: E501


        :return: The subject_organizational_unit of this ApiCertificate.  # noqa: E501
        :rtype: str
        """
        return self._subject_organizational_unit

    @subject_organizational_unit.setter
    def subject_organizational_unit(self, subject_organizational_unit):
        """Sets the subject_organizational_unit of this ApiCertificate.


        :param subject_organizational_unit: The subject_organizational_unit of this ApiCertificate.  # noqa: E501
        :type: str
        """

        self._subject_organizational_unit = subject_organizational_unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiCertificate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApiCertificate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class StackTraceElement(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'method_name': 'str',
        'file_name': 'str',
        'line_number': 'int',
        'class_name': 'str',
        'native_method': 'bool'
    }

    attribute_map = {
        'method_name': 'methodName',
        'file_name': 'fileName',
        'line_number': 'lineNumber',
        'class_name': 'className',
        'native_method': 'nativeMethod'
    }

    def __init__(self, method_name=None, file_name=None, line_number=None, class_name=None, native_method=None, local_vars_configuration=None):  # noqa: E501
        """StackTraceElement - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._method_name = None
        self._file_name = None
        self._line_number = None
        self._class_name = None
        self._native_method = None
        self.discriminator = None

        if method_name is not None:
            self.method_name = method_name
        if file_name is not None:
            self.file_name = file_name
        if line_number is not None:
            self.line_number = line_number
        if class_name is not None:
            self.class_name = class_name
        if native_method is not None:
            self.native_method = native_method

    @property
    def method_name(self):
        """Gets the method_name of this StackTraceElement.  # noqa: E501


        :return: The method_name of this StackTraceElement.  # noqa: E501
        :rtype: str
        """
        return self._method_name

    @method_name.setter
    def method_name(self, method_name):
        """Sets the method_name of this StackTraceElement.


        :param method_name: The method_name of this StackTraceElement.  # noqa: E501
        :type: str
        """

        self._method_name = method_name

    @property
    def file_name(self):
        """Gets the file_name of this StackTraceElement.  # noqa: E501


        :return: The file_name of this StackTraceElement.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this StackTraceElement.


        :param file_name: The file_name of this StackTraceElement.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def line_number(self):
        """Gets the line_number of this StackTraceElement.  # noqa: E501


        :return: The line_number of this StackTraceElement.  # noqa: E501
        :rtype: int
        """
        return self._line_number

    @line_number.setter
    def line_number(self, line_number):
        """Sets the line_number of this StackTraceElement.


        :param line_number: The line_number of this StackTraceElement.  # noqa: E501
        :type: int
        """

        self._line_number = line_number

    @property
    def class_name(self):
        """Gets the class_name of this StackTraceElement.  # noqa: E501


        :return: The class_name of this StackTraceElement.  # noqa: E501
        :rtype: str
        """
        return self._class_name

    @class_name.setter
    def class_name(self, class_name):
        """Sets the class_name of this StackTraceElement.


        :param class_name: The class_name of this StackTraceElement.  # noqa: E501
        :type: str
        """

        self._class_name = class_name

    @property
    def native_method(self):
        """Gets the native_method of this StackTraceElement.  # noqa: E501


        :return: The native_method of this StackTraceElement.  # noqa: E501
        :rtype: bool
        """
        return self._native_method

    @native_method.setter
    def native_method(self, native_method):
        """Sets the native_method of this StackTraceElement.


        :param native_method: The native_method of this StackTraceElement.  # noqa: E501
        :type: bool
        """

        self._native_method = native_method

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StackTraceElement):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StackTraceElement):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class AbstractApiRepository(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'format': 'str',
        'type': 'str',
        'url': 'str',
        'online': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'format': 'format',
        'type': 'type',
        'url': 'url',
        'online': 'online'
    }

    def __init__(self, name=None, format=None, type=None, url=None, online=None, local_vars_configuration=None):  # noqa: E501
        """AbstractApiRepository - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._format = None
        self._type = None
        self._url = None
        self._online = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if format is not None:
            self.format = format
        if type is not None:
            self.type = type
        if url is not None:
            self.url = url
        self.online = online

    @property
    def name(self):
        """Gets the name of this AbstractApiRepository.  # noqa: E501

        A unique identifier for this repository  # noqa: E501

        :return: The name of this AbstractApiRepository.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractApiRepository.

        A unique identifier for this repository  # noqa: E501

        :param name: The name of this AbstractApiRepository.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and not re.search(r'^[a-zA-Z0-9\-]{1}[a-zA-Z0-9_\-\.]*$', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^[a-zA-Z0-9\-]{1}[a-zA-Z0-9_\-\.]*$/`")  # noqa: E501

        self._name = name

    @property
    def format(self):
        """Gets the format of this AbstractApiRepository.  # noqa: E501

        Component format held in this repository  # noqa: E501

        :return: The format of this AbstractApiRepository.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this AbstractApiRepository.

        Component format held in this repository  # noqa: E501

        :param format: The format of this AbstractApiRepository.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def type(self):
        """Gets the type of this AbstractApiRepository.  # noqa: E501

        Controls if deployments of and updates to artifacts are allowed  # noqa: E501

        :return: The type of this AbstractApiRepository.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this AbstractApiRepository.

        Controls if deployments of and updates to artifacts are allowed  # noqa: E501

        :param type: The type of this AbstractApiRepository.  # noqa: E501
        :type: str
        """
        allowed_values = ["hosted", "proxy", "group"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def url(self):
        """Gets the url of this AbstractApiRepository.  # noqa: E501

        URL to the repository  # noqa: E501

        :return: The url of this AbstractApiRepository.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AbstractApiRepository.

        URL to the repository  # noqa: E501

        :param url: The url of this AbstractApiRepository.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def online(self):
        """Gets the online of this AbstractApiRepository.  # noqa: E501

        Whether this repository accepts incoming requests  # noqa: E501

        :return: The online of this AbstractApiRepository.  # noqa: E501
        :rtype: bool
        """
        return self._online

    @online.setter
    def online(self, online):
        """Sets the online of this AbstractApiRepository.

        Whether this repository accepts incoming requests  # noqa: E501

        :param online: The online of this AbstractApiRepository.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and online is None:  # noqa: E501
            raise ValueError("Invalid value for `online`, must not be `None`")  # noqa: E501

        self._online = online

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AbstractApiRepository):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AbstractApiRepository):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from nexus_api_python_client.api_client import ApiClient
from nexus_api_python_client.exceptions import (
    ApiTypeError,
    ApiValueError
)


class SearchApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def search(self, **kwargs):  # noqa: E501
        """Search components  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str continuation_token: A token returned by a prior request. If present, the next page of results are returned
        :param str sort: The field to sort the results against, if left empty, a sort based on match weight will be used.
        :param str direction: The direction to sort records in, defaults to ascending ('asc') for all sort fields, except version, which defaults to descending ('desc')
        :param int timeout: How long to wait for search results in seconds. If this value is not provided, the system default timeout will be used.
        :param str q: Query by keyword
        :param str repository: Repository name
        :param str format: Query by format
        :param str group: Component group
        :param str name: Component name
        :param str version: Component version
        :param str md5: Specific MD5 hash of component's asset
        :param str sha1: Specific SHA-1 hash of component's asset
        :param str sha256: Specific SHA-256 hash of component's asset
        :param str sha512: Specific SHA-512 hash of component's asset
        :param str prerelease: Prerelease version flag
        :param str docker_image_name: Docker image name
        :param str docker_image_tag: Docker image tag
        :param str docker_layer_id: Docker layer ID
        :param str docker_content_digest: Docker content digest
        :param str maven_group_id: Maven groupId
        :param str maven_artifact_id: Maven artifactId
        :param str maven_base_version: Maven base version
        :param str maven_extension: Maven extension of component's asset
        :param str maven_classifier: Maven classifier of component's asset
        :param str npm_scope: NPM scope
        :param str nuget_id: Nuget id
        :param str nuget_tags: Nuget tags
        :param str pypi_classifiers: PyPi classifiers
        :param str pypi_description: PyPi description
        :param str pypi_keywords: PyPi keywords
        :param str pypi_summary: PyPi summary
        :param str rubygems_description: RubyGems description
        :param str rubygems_platform: RubyGems platform
        :param str rubygems_summary: RubyGems summary
        :param str yum_architecture: Yum architecture
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageComponentXO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.search_with_http_info(**kwargs)  # noqa: E501

    def search_with_http_info(self, **kwargs):  # noqa: E501
        """Search components  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str continuation_token: A token returned by a prior request. If present, the next page of results are returned
        :param str sort: The field to sort the results against, if left empty, a sort based on match weight will be used.
        :param str direction: The direction to sort records in, defaults to ascending ('asc') for all sort fields, except version, which defaults to descending ('desc')
        :param int timeout: How long to wait for search results in seconds. If this value is not provided, the system default timeout will be used.
        :param str q: Query by keyword
        :param str repository: Repository name
        :param str format: Query by format
        :param str group: Component group
        :param str name: Component name
        :param str version: Component version
        :param str md5: Specific MD5 hash of component's asset
        :param str sha1: Specific SHA-1 hash of component's asset
        :param str sha256: Specific SHA-256 hash of component's asset
        :param str sha512: Specific SHA-512 hash of component's asset
        :param str prerelease: Prerelease version flag
        :param str docker_image_name: Docker image name
        :param str docker_image_tag: Docker image tag
        :param str docker_layer_id: Docker layer ID
        :param str docker_content_digest: Docker content digest
        :param str maven_group_id: Maven groupId
        :param str maven_artifact_id: Maven artifactId
        :param str maven_base_version: Maven base version
        :param str maven_extension: Maven extension of component's asset
        :param str maven_classifier: Maven classifier of component's asset
        :param str npm_scope: NPM scope
        :param str nuget_id: Nuget id
        :param str nuget_tags: Nuget tags
        :param str pypi_classifiers: PyPi classifiers
        :param str pypi_description: PyPi description
        :param str pypi_keywords: PyPi keywords
        :param str pypi_summary: PyPi summary
        :param str rubygems_description: RubyGems description
        :param str rubygems_platform: RubyGems platform
        :param str rubygems_summary: RubyGems summary
        :param str yum_architecture: Yum architecture
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageComponentXO, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['continuation_token', 'sort', 'direction', 'timeout', 'q', 'repository', 'format', 'group', 'name', 'version', 'md5', 'sha1', 'sha256', 'sha512', 'prerelease', 'docker_image_name', 'docker_image_tag', 'docker_layer_id', 'docker_content_digest', 'maven_group_id', 'maven_artifact_id', 'maven_base_version', 'maven_extension', 'maven_classifier', 'npm_scope', 'nuget_id', 'nuget_tags', 'pypi_classifiers', 'pypi_description', 'pypi_keywords', 'pypi_summary', 'rubygems_description', 'rubygems_platform', 'rubygems_summary', 'yum_architecture']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'continuation_token' in local_var_params and local_var_params['continuation_token'] is not None:  # noqa: E501
            query_params.append(('continuationToken', local_var_params['continuation_token']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'direction' in local_var_params and local_var_params['direction'] is not None:  # noqa: E501
            query_params.append(('direction', local_var_params['direction']))  # noqa: E501
        if 'timeout' in local_var_params and local_var_params['timeout'] is not None:  # noqa: E501
            query_params.append(('timeout', local_var_params['timeout']))  # noqa: E501
        if 'q' in local_var_params and local_var_params['q'] is not None:  # noqa: E501
            query_params.append(('q', local_var_params['q']))  # noqa: E501
        if 'repository' in local_var_params and local_var_params['repository'] is not None:  # noqa: E501
            query_params.append(('repository', local_var_params['repository']))  # noqa: E501
        if 'format' in local_var_params and local_var_params['format'] is not None:  # noqa: E501
            query_params.append(('format', local_var_params['format']))  # noqa: E501
        if 'group' in local_var_params and local_var_params['group'] is not None:  # noqa: E501
            query_params.append(('group', local_var_params['group']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'version' in local_var_params and local_var_params['version'] is not None:  # noqa: E501
            query_params.append(('version', local_var_params['version']))  # noqa: E501
        if 'md5' in local_var_params and local_var_params['md5'] is not None:  # noqa: E501
            query_params.append(('md5', local_var_params['md5']))  # noqa: E501
        if 'sha1' in local_var_params and local_var_params['sha1'] is not None:  # noqa: E501
            query_params.append(('sha1', local_var_params['sha1']))  # noqa: E501
        if 'sha256' in local_var_params and local_var_params['sha256'] is not None:  # noqa: E501
            query_params.append(('sha256', local_var_params['sha256']))  # noqa: E501
        if 'sha512' in local_var_params and local_var_params['sha512'] is not None:  # noqa: E501
            query_params.append(('sha512', local_var_params['sha512']))  # noqa: E501
        if 'prerelease' in local_var_params and local_var_params['prerelease'] is not None:  # noqa: E501
            query_params.append(('prerelease', local_var_params['prerelease']))  # noqa: E501
        if 'docker_image_name' in local_var_params and local_var_params['docker_image_name'] is not None:  # noqa: E501
            query_params.append(('docker.imageName', local_var_params['docker_image_name']))  # noqa: E501
        if 'docker_image_tag' in local_var_params and local_var_params['docker_image_tag'] is not None:  # noqa: E501
            query_params.append(('docker.imageTag', local_var_params['docker_image_tag']))  # noqa: E501
        if 'docker_layer_id' in local_var_params and local_var_params['docker_layer_id'] is not None:  # noqa: E501
            query_params.append(('docker.layerId', local_var_params['docker_layer_id']))  # noqa: E501
        if 'docker_content_digest' in local_var_params and local_var_params['docker_content_digest'] is not None:  # noqa: E501
            query_params.append(('docker.contentDigest', local_var_params['docker_content_digest']))  # noqa: E501
        if 'maven_group_id' in local_var_params and local_var_params['maven_group_id'] is not None:  # noqa: E501
            query_params.append(('maven.groupId', local_var_params['maven_group_id']))  # noqa: E501
        if 'maven_artifact_id' in local_var_params and local_var_params['maven_artifact_id'] is not None:  # noqa: E501
            query_params.append(('maven.artifactId', local_var_params['maven_artifact_id']))  # noqa: E501
        if 'maven_base_version' in local_var_params and local_var_params['maven_base_version'] is not None:  # noqa: E501
            query_params.append(('maven.baseVersion', local_var_params['maven_base_version']))  # noqa: E501
        if 'maven_extension' in local_var_params and local_var_params['maven_extension'] is not None:  # noqa: E501
            query_params.append(('maven.extension', local_var_params['maven_extension']))  # noqa: E501
        if 'maven_classifier' in local_var_params and local_var_params['maven_classifier'] is not None:  # noqa: E501
            query_params.append(('maven.classifier', local_var_params['maven_classifier']))  # noqa: E501
        if 'npm_scope' in local_var_params and local_var_params['npm_scope'] is not None:  # noqa: E501
            query_params.append(('npm.scope', local_var_params['npm_scope']))  # noqa: E501
        if 'nuget_id' in local_var_params and local_var_params['nuget_id'] is not None:  # noqa: E501
            query_params.append(('nuget.id', local_var_params['nuget_id']))  # noqa: E501
        if 'nuget_tags' in local_var_params and local_var_params['nuget_tags'] is not None:  # noqa: E501
            query_params.append(('nuget.tags', local_var_params['nuget_tags']))  # noqa: E501
        if 'pypi_classifiers' in local_var_params and local_var_params['pypi_classifiers'] is not None:  # noqa: E501
            query_params.append(('pypi.classifiers', local_var_params['pypi_classifiers']))  # noqa: E501
        if 'pypi_description' in local_var_params and local_var_params['pypi_description'] is not None:  # noqa: E501
            query_params.append(('pypi.description', local_var_params['pypi_description']))  # noqa: E501
        if 'pypi_keywords' in local_var_params and local_var_params['pypi_keywords'] is not None:  # noqa: E501
            query_params.append(('pypi.keywords', local_var_params['pypi_keywords']))  # noqa: E501
        if 'pypi_summary' in local_var_params and local_var_params['pypi_summary'] is not None:  # noqa: E501
            query_params.append(('pypi.summary', local_var_params['pypi_summary']))  # noqa: E501
        if 'rubygems_description' in local_var_params and local_var_params['rubygems_description'] is not None:  # noqa: E501
            query_params.append(('rubygems.description', local_var_params['rubygems_description']))  # noqa: E501
        if 'rubygems_platform' in local_var_params and local_var_params['rubygems_platform'] is not None:  # noqa: E501
            query_params.append(('rubygems.platform', local_var_params['rubygems_platform']))  # noqa: E501
        if 'rubygems_summary' in local_var_params and local_var_params['rubygems_summary'] is not None:  # noqa: E501
            query_params.append(('rubygems.summary', local_var_params['rubygems_summary']))  # noqa: E501
        if 'yum_architecture' in local_var_params and local_var_params['yum_architecture'] is not None:  # noqa: E501
            query_params.append(('yum.architecture', local_var_params['yum_architecture']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageComponentXO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_and_download_assets(self, **kwargs):  # noqa: E501
        """Search and download asset  # noqa: E501

        Returns a 302 Found with location header field set to download URL. Unless a sort parameter is supplied, the search must return a single asset to receive download URL.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_and_download_assets(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sort: The field to sort the results against, if left empty and more than 1 result is returned, the request will fail.
        :param str direction: The direction to sort records in, defaults to ascending ('asc') for all sort fields, except version, which defaults to descending ('desc')
        :param int timeout: How long to wait for search results in seconds. If this value is not provided, the system default timeout will be used.
        :param str q: Query by keyword
        :param str repository: Repository name
        :param str format: Query by format
        :param str group: Component group
        :param str name: Component name
        :param str version: Component version
        :param str md5: Specific MD5 hash of component's asset
        :param str sha1: Specific SHA-1 hash of component's asset
        :param str sha256: Specific SHA-256 hash of component's asset
        :param str sha512: Specific SHA-512 hash of component's asset
        :param str prerelease: Prerelease version flag
        :param str docker_image_name: Docker image name
        :param str docker_image_tag: Docker image tag
        :param str docker_layer_id: Docker layer ID
        :param str docker_content_digest: Docker content digest
        :param str maven_group_id: Maven groupId
        :param str maven_artifact_id: Maven artifactId
        :param str maven_base_version: Maven base version
        :param str maven_extension: Maven extension of component's asset
        :param str maven_classifier: Maven classifier of component's asset
        :param str npm_scope: NPM scope
        :param str nuget_id: Nuget id
        :param str nuget_tags: Nuget tags
        :param str pypi_classifiers: PyPi classifiers
        :param str pypi_description: PyPi description
        :param str pypi_keywords: PyPi keywords
        :param str pypi_summary: PyPi summary
        :param str rubygems_description: RubyGems description
        :param str rubygems_platform: RubyGems platform
        :param str rubygems_summary: RubyGems summary
        :param str yum_architecture: Yum architecture
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.search_and_download_assets_with_http_info(**kwargs)  # noqa: E501

    def search_and_download_assets_with_http_info(self, **kwargs):  # noqa: E501
        """Search and download asset  # noqa: E501

        Returns a 302 Found with location header field set to download URL. Unless a sort parameter is supplied, the search must return a single asset to receive download URL.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_and_download_assets_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sort: The field to sort the results against, if left empty and more than 1 result is returned, the request will fail.
        :param str direction: The direction to sort records in, defaults to ascending ('asc') for all sort fields, except version, which defaults to descending ('desc')
        :param int timeout: How long to wait for search results in seconds. If this value is not provided, the system default timeout will be used.
        :param str q: Query by keyword
        :param str repository: Repository name
        :param str format: Query by format
        :param str group: Component group
        :param str name: Component name
        :param str version: Component version
        :param str md5: Specific MD5 hash of component's asset
        :param str sha1: Specific SHA-1 hash of component's asset
        :param str sha256: Specific SHA-256 hash of component's asset
        :param str sha512: Specific SHA-512 hash of component's asset
        :param str prerelease: Prerelease version flag
        :param str docker_image_name: Docker image name
        :param str docker_image_tag: Docker image tag
        :param str docker_layer_id: Docker layer ID
        :param str docker_content_digest: Docker content digest
        :param str maven_group_id: Maven groupId
        :param str maven_artifact_id: Maven artifactId
        :param str maven_base_version: Maven base version
        :param str maven_extension: Maven extension of component's asset
        :param str maven_classifier: Maven classifier of component's asset
        :param str npm_scope: NPM scope
        :param str nuget_id: Nuget id
        :param str nuget_tags: Nuget tags
        :param str pypi_classifiers: PyPi classifiers
        :param str pypi_description: PyPi description
        :param str pypi_keywords: PyPi keywords
        :param str pypi_summary: PyPi summary
        :param str rubygems_description: RubyGems description
        :param str rubygems_platform: RubyGems platform
        :param str rubygems_summary: RubyGems summary
        :param str yum_architecture: Yum architecture
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['sort', 'direction', 'timeout', 'q', 'repository', 'format', 'group', 'name', 'version', 'md5', 'sha1', 'sha256', 'sha512', 'prerelease', 'docker_image_name', 'docker_image_tag', 'docker_layer_id', 'docker_content_digest', 'maven_group_id', 'maven_artifact_id', 'maven_base_version', 'maven_extension', 'maven_classifier', 'npm_scope', 'nuget_id', 'nuget_tags', 'pypi_classifiers', 'pypi_description', 'pypi_keywords', 'pypi_summary', 'rubygems_description', 'rubygems_platform', 'rubygems_summary', 'yum_architecture']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_and_download_assets" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'direction' in local_var_params and local_var_params['direction'] is not None:  # noqa: E501
            query_params.append(('direction', local_var_params['direction']))  # noqa: E501
        if 'timeout' in local_var_params and local_var_params['timeout'] is not None:  # noqa: E501
            query_params.append(('timeout', local_var_params['timeout']))  # noqa: E501
        if 'q' in local_var_params and local_var_params['q'] is not None:  # noqa: E501
            query_params.append(('q', local_var_params['q']))  # noqa: E501
        if 'repository' in local_var_params and local_var_params['repository'] is not None:  # noqa: E501
            query_params.append(('repository', local_var_params['repository']))  # noqa: E501
        if 'format' in local_var_params and local_var_params['format'] is not None:  # noqa: E501
            query_params.append(('format', local_var_params['format']))  # noqa: E501
        if 'group' in local_var_params and local_var_params['group'] is not None:  # noqa: E501
            query_params.append(('group', local_var_params['group']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'version' in local_var_params and local_var_params['version'] is not None:  # noqa: E501
            query_params.append(('version', local_var_params['version']))  # noqa: E501
        if 'md5' in local_var_params and local_var_params['md5'] is not None:  # noqa: E501
            query_params.append(('md5', local_var_params['md5']))  # noqa: E501
        if 'sha1' in local_var_params and local_var_params['sha1'] is not None:  # noqa: E501
            query_params.append(('sha1', local_var_params['sha1']))  # noqa: E501
        if 'sha256' in local_var_params and local_var_params['sha256'] is not None:  # noqa: E501
            query_params.append(('sha256', local_var_params['sha256']))  # noqa: E501
        if 'sha512' in local_var_params and local_var_params['sha512'] is not None:  # noqa: E501
            query_params.append(('sha512', local_var_params['sha512']))  # noqa: E501
        if 'prerelease' in local_var_params and local_var_params['prerelease'] is not None:  # noqa: E501
            query_params.append(('prerelease', local_var_params['prerelease']))  # noqa: E501
        if 'docker_image_name' in local_var_params and local_var_params['docker_image_name'] is not None:  # noqa: E501
            query_params.append(('docker.imageName', local_var_params['docker_image_name']))  # noqa: E501
        if 'docker_image_tag' in local_var_params and local_var_params['docker_image_tag'] is not None:  # noqa: E501
            query_params.append(('docker.imageTag', local_var_params['docker_image_tag']))  # noqa: E501
        if 'docker_layer_id' in local_var_params and local_var_params['docker_layer_id'] is not None:  # noqa: E501
            query_params.append(('docker.layerId', local_var_params['docker_layer_id']))  # noqa: E501
        if 'docker_content_digest' in local_var_params and local_var_params['docker_content_digest'] is not None:  # noqa: E501
            query_params.append(('docker.contentDigest', local_var_params['docker_content_digest']))  # noqa: E501
        if 'maven_group_id' in local_var_params and local_var_params['maven_group_id'] is not None:  # noqa: E501
            query_params.append(('maven.groupId', local_var_params['maven_group_id']))  # noqa: E501
        if 'maven_artifact_id' in local_var_params and local_var_params['maven_artifact_id'] is not None:  # noqa: E501
            query_params.append(('maven.artifactId', local_var_params['maven_artifact_id']))  # noqa: E501
        if 'maven_base_version' in local_var_params and local_var_params['maven_base_version'] is not None:  # noqa: E501
            query_params.append(('maven.baseVersion', local_var_params['maven_base_version']))  # noqa: E501
        if 'maven_extension' in local_var_params and local_var_params['maven_extension'] is not None:  # noqa: E501
            query_params.append(('maven.extension', local_var_params['maven_extension']))  # noqa: E501
        if 'maven_classifier' in local_var_params and local_var_params['maven_classifier'] is not None:  # noqa: E501
            query_params.append(('maven.classifier', local_var_params['maven_classifier']))  # noqa: E501
        if 'npm_scope' in local_var_params and local_var_params['npm_scope'] is not None:  # noqa: E501
            query_params.append(('npm.scope', local_var_params['npm_scope']))  # noqa: E501
        if 'nuget_id' in local_var_params and local_var_params['nuget_id'] is not None:  # noqa: E501
            query_params.append(('nuget.id', local_var_params['nuget_id']))  # noqa: E501
        if 'nuget_tags' in local_var_params and local_var_params['nuget_tags'] is not None:  # noqa: E501
            query_params.append(('nuget.tags', local_var_params['nuget_tags']))  # noqa: E501
        if 'pypi_classifiers' in local_var_params and local_var_params['pypi_classifiers'] is not None:  # noqa: E501
            query_params.append(('pypi.classifiers', local_var_params['pypi_classifiers']))  # noqa: E501
        if 'pypi_description' in local_var_params and local_var_params['pypi_description'] is not None:  # noqa: E501
            query_params.append(('pypi.description', local_var_params['pypi_description']))  # noqa: E501
        if 'pypi_keywords' in local_var_params and local_var_params['pypi_keywords'] is not None:  # noqa: E501
            query_params.append(('pypi.keywords', local_var_params['pypi_keywords']))  # noqa: E501
        if 'pypi_summary' in local_var_params and local_var_params['pypi_summary'] is not None:  # noqa: E501
            query_params.append(('pypi.summary', local_var_params['pypi_summary']))  # noqa: E501
        if 'rubygems_description' in local_var_params and local_var_params['rubygems_description'] is not None:  # noqa: E501
            query_params.append(('rubygems.description', local_var_params['rubygems_description']))  # noqa: E501
        if 'rubygems_platform' in local_var_params and local_var_params['rubygems_platform'] is not None:  # noqa: E501
            query_params.append(('rubygems.platform', local_var_params['rubygems_platform']))  # noqa: E501
        if 'rubygems_summary' in local_var_params and local_var_params['rubygems_summary'] is not None:  # noqa: E501
            query_params.append(('rubygems.summary', local_var_params['rubygems_summary']))  # noqa: E501
        if 'yum_architecture' in local_var_params and local_var_params['yum_architecture'] is not None:  # noqa: E501
            query_params.append(('yum.architecture', local_var_params['yum_architecture']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/search/assets/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_assets(self, **kwargs):  # noqa: E501
        """Search assets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_assets(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str continuation_token: A token returned by a prior request. If present, the next page of results are returned
        :param str sort: The field to sort the results against, if left empty, a sort based on match weight will be used.
        :param str direction: The direction to sort records in, defaults to ascending ('asc') for all sort fields, except version, which defaults to descending ('desc')
        :param int timeout: How long to wait for search results in seconds. If this value is not provided, the system default timeout will be used.
        :param str q: Query by keyword
        :param str repository: Repository name
        :param str format: Query by format
        :param str group: Component group
        :param str name: Component name
        :param str version: Component version
        :param str md5: Specific MD5 hash of component's asset
        :param str sha1: Specific SHA-1 hash of component's asset
        :param str sha256: Specific SHA-256 hash of component's asset
        :param str sha512: Specific SHA-512 hash of component's asset
        :param str prerelease: Prerelease version flag
        :param str docker_image_name: Docker image name
        :param str docker_image_tag: Docker image tag
        :param str docker_layer_id: Docker layer ID
        :param str docker_content_digest: Docker content digest
        :param str maven_group_id: Maven groupId
        :param str maven_artifact_id: Maven artifactId
        :param str maven_base_version: Maven base version
        :param str maven_extension: Maven extension of component's asset
        :param str maven_classifier: Maven classifier of component's asset
        :param str npm_scope: NPM scope
        :param str nuget_id: Nuget id
        :param str nuget_tags: Nuget tags
        :param str pypi_classifiers: PyPi classifiers
        :param str pypi_description: PyPi description
        :param str pypi_keywords: PyPi keywords
        :param str pypi_summary: PyPi summary
        :param str rubygems_description: RubyGems description
        :param str rubygems_platform: RubyGems platform
        :param str rubygems_summary: RubyGems summary
        :param str yum_architecture: Yum architecture
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PageAssetXO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.search_assets_with_http_info(**kwargs)  # noqa: E501

    def search_assets_with_http_info(self, **kwargs):  # noqa: E501
        """Search assets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_assets_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str continuation_token: A token returned by a prior request. If present, the next page of results are returned
        :param str sort: The field to sort the results against, if left empty, a sort based on match weight will be used.
        :param str direction: The direction to sort records in, defaults to ascending ('asc') for all sort fields, except version, which defaults to descending ('desc')
        :param int timeout: How long to wait for search results in seconds. If this value is not provided, the system default timeout will be used.
        :param str q: Query by keyword
        :param str repository: Repository name
        :param str format: Query by format
        :param str group: Component group
        :param str name: Component name
        :param str version: Component version
        :param str md5: Specific MD5 hash of component's asset
        :param str sha1: Specific SHA-1 hash of component's asset
        :param str sha256: Specific SHA-256 hash of component's asset
        :param str sha512: Specific SHA-512 hash of component's asset
        :param str prerelease: Prerelease version flag
        :param str docker_image_name: Docker image name
        :param str docker_image_tag: Docker image tag
        :param str docker_layer_id: Docker layer ID
        :param str docker_content_digest: Docker content digest
        :param str maven_group_id: Maven groupId
        :param str maven_artifact_id: Maven artifactId
        :param str maven_base_version: Maven base version
        :param str maven_extension: Maven extension of component's asset
        :param str maven_classifier: Maven classifier of component's asset
        :param str npm_scope: NPM scope
        :param str nuget_id: Nuget id
        :param str nuget_tags: Nuget tags
        :param str pypi_classifiers: PyPi classifiers
        :param str pypi_description: PyPi description
        :param str pypi_keywords: PyPi keywords
        :param str pypi_summary: PyPi summary
        :param str rubygems_description: RubyGems description
        :param str rubygems_platform: RubyGems platform
        :param str rubygems_summary: RubyGems summary
        :param str yum_architecture: Yum architecture
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PageAssetXO, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['continuation_token', 'sort', 'direction', 'timeout', 'q', 'repository', 'format', 'group', 'name', 'version', 'md5', 'sha1', 'sha256', 'sha512', 'prerelease', 'docker_image_name', 'docker_image_tag', 'docker_layer_id', 'docker_content_digest', 'maven_group_id', 'maven_artifact_id', 'maven_base_version', 'maven_extension', 'maven_classifier', 'npm_scope', 'nuget_id', 'nuget_tags', 'pypi_classifiers', 'pypi_description', 'pypi_keywords', 'pypi_summary', 'rubygems_description', 'rubygems_platform', 'rubygems_summary', 'yum_architecture']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_assets" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'continuation_token' in local_var_params and local_var_params['continuation_token'] is not None:  # noqa: E501
            query_params.append(('continuationToken', local_var_params['continuation_token']))  # noqa: E501
        if 'sort' in local_var_params and local_var_params['sort'] is not None:  # noqa: E501
            query_params.append(('sort', local_var_params['sort']))  # noqa: E501
        if 'direction' in local_var_params and local_var_params['direction'] is not None:  # noqa: E501
            query_params.append(('direction', local_var_params['direction']))  # noqa: E501
        if 'timeout' in local_var_params and local_var_params['timeout'] is not None:  # noqa: E501
            query_params.append(('timeout', local_var_params['timeout']))  # noqa: E501
        if 'q' in local_var_params and local_var_params['q'] is not None:  # noqa: E501
            query_params.append(('q', local_var_params['q']))  # noqa: E501
        if 'repository' in local_var_params and local_var_params['repository'] is not None:  # noqa: E501
            query_params.append(('repository', local_var_params['repository']))  # noqa: E501
        if 'format' in local_var_params and local_var_params['format'] is not None:  # noqa: E501
            query_params.append(('format', local_var_params['format']))  # noqa: E501
        if 'group' in local_var_params and local_var_params['group'] is not None:  # noqa: E501
            query_params.append(('group', local_var_params['group']))  # noqa: E501
        if 'name' in local_var_params and local_var_params['name'] is not None:  # noqa: E501
            query_params.append(('name', local_var_params['name']))  # noqa: E501
        if 'version' in local_var_params and local_var_params['version'] is not None:  # noqa: E501
            query_params.append(('version', local_var_params['version']))  # noqa: E501
        if 'md5' in local_var_params and local_var_params['md5'] is not None:  # noqa: E501
            query_params.append(('md5', local_var_params['md5']))  # noqa: E501
        if 'sha1' in local_var_params and local_var_params['sha1'] is not None:  # noqa: E501
            query_params.append(('sha1', local_var_params['sha1']))  # noqa: E501
        if 'sha256' in local_var_params and local_var_params['sha256'] is not None:  # noqa: E501
            query_params.append(('sha256', local_var_params['sha256']))  # noqa: E501
        if 'sha512' in local_var_params and local_var_params['sha512'] is not None:  # noqa: E501
            query_params.append(('sha512', local_var_params['sha512']))  # noqa: E501
        if 'prerelease' in local_var_params and local_var_params['prerelease'] is not None:  # noqa: E501
            query_params.append(('prerelease', local_var_params['prerelease']))  # noqa: E501
        if 'docker_image_name' in local_var_params and local_var_params['docker_image_name'] is not None:  # noqa: E501
            query_params.append(('docker.imageName', local_var_params['docker_image_name']))  # noqa: E501
        if 'docker_image_tag' in local_var_params and local_var_params['docker_image_tag'] is not None:  # noqa: E501
            query_params.append(('docker.imageTag', local_var_params['docker_image_tag']))  # noqa: E501
        if 'docker_layer_id' in local_var_params and local_var_params['docker_layer_id'] is not None:  # noqa: E501
            query_params.append(('docker.layerId', local_var_params['docker_layer_id']))  # noqa: E501
        if 'docker_content_digest' in local_var_params and local_var_params['docker_content_digest'] is not None:  # noqa: E501
            query_params.append(('docker.contentDigest', local_var_params['docker_content_digest']))  # noqa: E501
        if 'maven_group_id' in local_var_params and local_var_params['maven_group_id'] is not None:  # noqa: E501
            query_params.append(('maven.groupId', local_var_params['maven_group_id']))  # noqa: E501
        if 'maven_artifact_id' in local_var_params and local_var_params['maven_artifact_id'] is not None:  # noqa: E501
            query_params.append(('maven.artifactId', local_var_params['maven_artifact_id']))  # noqa: E501
        if 'maven_base_version' in local_var_params and local_var_params['maven_base_version'] is not None:  # noqa: E501
            query_params.append(('maven.baseVersion', local_var_params['maven_base_version']))  # noqa: E501
        if 'maven_extension' in local_var_params and local_var_params['maven_extension'] is not None:  # noqa: E501
            query_params.append(('maven.extension', local_var_params['maven_extension']))  # noqa: E501
        if 'maven_classifier' in local_var_params and local_var_params['maven_classifier'] is not None:  # noqa: E501
            query_params.append(('maven.classifier', local_var_params['maven_classifier']))  # noqa: E501
        if 'npm_scope' in local_var_params and local_var_params['npm_scope'] is not None:  # noqa: E501
            query_params.append(('npm.scope', local_var_params['npm_scope']))  # noqa: E501
        if 'nuget_id' in local_var_params and local_var_params['nuget_id'] is not None:  # noqa: E501
            query_params.append(('nuget.id', local_var_params['nuget_id']))  # noqa: E501
        if 'nuget_tags' in local_var_params and local_var_params['nuget_tags'] is not None:  # noqa: E501
            query_params.append(('nuget.tags', local_var_params['nuget_tags']))  # noqa: E501
        if 'pypi_classifiers' in local_var_params and local_var_params['pypi_classifiers'] is not None:  # noqa: E501
            query_params.append(('pypi.classifiers', local_var_params['pypi_classifiers']))  # noqa: E501
        if 'pypi_description' in local_var_params and local_var_params['pypi_description'] is not None:  # noqa: E501
            query_params.append(('pypi.description', local_var_params['pypi_description']))  # noqa: E501
        if 'pypi_keywords' in local_var_params and local_var_params['pypi_keywords'] is not None:  # noqa: E501
            query_params.append(('pypi.keywords', local_var_params['pypi_keywords']))  # noqa: E501
        if 'pypi_summary' in local_var_params and local_var_params['pypi_summary'] is not None:  # noqa: E501
            query_params.append(('pypi.summary', local_var_params['pypi_summary']))  # noqa: E501
        if 'rubygems_description' in local_var_params and local_var_params['rubygems_description'] is not None:  # noqa: E501
            query_params.append(('rubygems.description', local_var_params['rubygems_description']))  # noqa: E501
        if 'rubygems_platform' in local_var_params and local_var_params['rubygems_platform'] is not None:  # noqa: E501
            query_params.append(('rubygems.platform', local_var_params['rubygems_platform']))  # noqa: E501
        if 'rubygems_summary' in local_var_params and local_var_params['rubygems_summary'] is not None:  # noqa: E501
            query_params.append(('rubygems.summary', local_var_params['rubygems_summary']))  # noqa: E501
        if 'yum_architecture' in local_var_params and local_var_params['yum_architecture'] is not None:  # noqa: E501
            query_params.append(('yum.architecture', local_var_params['yum_architecture']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/search/assets', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PageAssetXO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class ApiLicenseDetailsXO(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'contact_email': 'str',
        'contact_company': 'str',
        'contact_name': 'str',
        'effective_date': 'datetime',
        'expiration_date': 'datetime',
        'license_type': 'str',
        'licensed_users': 'str',
        'fingerprint': 'str',
        'features': 'str'
    }

    attribute_map = {
        'contact_email': 'contactEmail',
        'contact_company': 'contactCompany',
        'contact_name': 'contactName',
        'effective_date': 'effectiveDate',
        'expiration_date': 'expirationDate',
        'license_type': 'licenseType',
        'licensed_users': 'licensedUsers',
        'fingerprint': 'fingerprint',
        'features': 'features'
    }

    def __init__(self, contact_email=None, contact_company=None, contact_name=None, effective_date=None, expiration_date=None, license_type=None, licensed_users=None, fingerprint=None, features=None, local_vars_configuration=None):  # noqa: E501
        """ApiLicenseDetailsXO - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._contact_email = None
        self._contact_company = None
        self._contact_name = None
        self._effective_date = None
        self._expiration_date = None
        self._license_type = None
        self._licensed_users = None
        self._fingerprint = None
        self._features = None
        self.discriminator = None

        if contact_email is not None:
            self.contact_email = contact_email
        if contact_company is not None:
            self.contact_company = contact_company
        if contact_name is not None:
            self.contact_name = contact_name
        if effective_date is not None:
            self.effective_date = effective_date
        if expiration_date is not None:
            self.expiration_date = expiration_date
        if license_type is not None:
            self.license_type = license_type
        if licensed_users is not None:
            self.licensed_users = licensed_users
        if fingerprint is not None:
            self.fingerprint = fingerprint
        if features is not None:
            self.features = features

    @property
    def contact_email(self):
        """Gets the contact_email of this ApiLicenseDetailsXO.  # noqa: E501


        :return: The contact_email of this ApiLicenseDetailsXO.  # noqa: E501
        :rtype: str
        """
        return self._contact_email

    @contact_email.setter
    def contact_email(self, contact_email):
        """Sets the contact_email of this ApiLicenseDetailsXO.


        :param contact_email: The contact_email of this ApiLicenseDetailsXO.  # noqa: E501
        :type: str
        """

        self._contact_email = contact_email

    @property
    def contact_company(self):
        """Gets the contact_company of this ApiLicenseDetailsXO.  # noqa: E501


        :return: The contact_company of this ApiLicenseDetailsXO.  # noqa: E501
        :rtype: str
        """
        return self._contact_company

    @contact_company.setter
    def contact_company(self, contact_company):
        """Sets the contact_company of this ApiLicenseDetailsXO.


        :param contact_company: The contact_company of this ApiLicenseDetailsXO.  # noqa: E501
        :type: str
        """

        self._contact_company = contact_company

    @property
    def contact_name(self):
        """Gets the contact_name of this ApiLicenseDetailsXO.  # noqa: E501


        :return: The contact_name of this ApiLicenseDetailsXO.  # noqa: E501
        :rtype: str
        """
        return self._contact_name

    @contact_name.setter
    def contact_name(self, contact_name):
        """Sets the contact_name of this ApiLicenseDetailsXO.


        :param contact_name: The contact_name of this ApiLicenseDetailsXO.  # noqa: E501
        :type: str
        """

        self._contact_name = contact_name

    @property
    def effective_date(self):
        """Gets the effective_date of this ApiLicenseDetailsXO.  # noqa: E501


        :return: The effective_date of this ApiLicenseDetailsXO.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """Sets the effective_date of this ApiLicenseDetailsXO.


        :param effective_date: The effective_date of this ApiLicenseDetailsXO.  # noqa: E501
        :type: datetime
        """

        self._effective_date = effective_date

    @property
    def expiration_date(self):
        """Gets the expiration_date of this ApiLicenseDetailsXO.  # noqa: E501


        :return: The expiration_date of this ApiLicenseDetailsXO.  # noqa: E501
        :rtype: datetime
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this ApiLicenseDetailsXO.


        :param expiration_date: The expiration_date of this ApiLicenseDetailsXO.  # noqa: E501
        :type: datetime
        """

        self._expiration_date = expiration_date

    @property
    def license_type(self):
        """Gets the license_type of this ApiLicenseDetailsXO.  # noqa: E501


        :return: The license_type of this ApiLicenseDetailsXO.  # noqa: E501
        :rtype: str
        """
        return self._license_type

    @license_type.setter
    def license_type(self, license_type):
        """Sets the license_type of this ApiLicenseDetailsXO.


        :param license_type: The license_type of this ApiLicenseDetailsXO.  # noqa: E501
        :type: str
        """

        self._license_type = license_type

    @property
    def licensed_users(self):
        """Gets the licensed_users of this ApiLicenseDetailsXO.  # noqa: E501


        :return: The licensed_users of this ApiLicenseDetailsXO.  # noqa: E501
        :rtype: str
        """
        return self._licensed_users

    @licensed_users.setter
    def licensed_users(self, licensed_users):
        """Sets the licensed_users of this ApiLicenseDetailsXO.


        :param licensed_users: The licensed_users of this ApiLicenseDetailsXO.  # noqa: E501
        :type: str
        """

        self._licensed_users = licensed_users

    @property
    def fingerprint(self):
        """Gets the fingerprint of this ApiLicenseDetailsXO.  # noqa: E501


        :return: The fingerprint of this ApiLicenseDetailsXO.  # noqa: E501
        :rtype: str
        """
        return self._fingerprint

    @fingerprint.setter
    def fingerprint(self, fingerprint):
        """Sets the fingerprint of this ApiLicenseDetailsXO.


        :param fingerprint: The fingerprint of this ApiLicenseDetailsXO.  # noqa: E501
        :type: str
        """

        self._fingerprint = fingerprint

    @property
    def features(self):
        """Gets the features of this ApiLicenseDetailsXO.  # noqa: E501


        :return: The features of this ApiLicenseDetailsXO.  # noqa: E501
        :rtype: str
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this ApiLicenseDetailsXO.


        :param features: The features of this ApiLicenseDetailsXO.  # noqa: E501
        :type: str
        """

        self._features = features

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiLicenseDetailsXO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApiLicenseDetailsXO):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class ApiEmailConfiguration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'enabled': 'bool',
        'host': 'str',
        'port': 'int',
        'username': 'str',
        'password': 'str',
        'from_address': 'str',
        'subject_prefix': 'str',
        'start_tls_enabled': 'bool',
        'start_tls_required': 'bool',
        'ssl_on_connect_enabled': 'bool',
        'ssl_server_identity_check_enabled': 'bool',
        'nexus_trust_store_enabled': 'bool'
    }

    attribute_map = {
        'enabled': 'enabled',
        'host': 'host',
        'port': 'port',
        'username': 'username',
        'password': 'password',
        'from_address': 'fromAddress',
        'subject_prefix': 'subjectPrefix',
        'start_tls_enabled': 'startTlsEnabled',
        'start_tls_required': 'startTlsRequired',
        'ssl_on_connect_enabled': 'sslOnConnectEnabled',
        'ssl_server_identity_check_enabled': 'sslServerIdentityCheckEnabled',
        'nexus_trust_store_enabled': 'nexusTrustStoreEnabled'
    }

    def __init__(self, enabled=None, host=None, port=None, username=None, password=None, from_address=None, subject_prefix=None, start_tls_enabled=None, start_tls_required=None, ssl_on_connect_enabled=None, ssl_server_identity_check_enabled=None, nexus_trust_store_enabled=None, local_vars_configuration=None):  # noqa: E501
        """ApiEmailConfiguration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._enabled = None
        self._host = None
        self._port = None
        self._username = None
        self._password = None
        self._from_address = None
        self._subject_prefix = None
        self._start_tls_enabled = None
        self._start_tls_required = None
        self._ssl_on_connect_enabled = None
        self._ssl_server_identity_check_enabled = None
        self._nexus_trust_store_enabled = None
        self.discriminator = None

        if enabled is not None:
            self.enabled = enabled
        if host is not None:
            self.host = host
        self.port = port
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if from_address is not None:
            self.from_address = from_address
        if subject_prefix is not None:
            self.subject_prefix = subject_prefix
        if start_tls_enabled is not None:
            self.start_tls_enabled = start_tls_enabled
        if start_tls_required is not None:
            self.start_tls_required = start_tls_required
        if ssl_on_connect_enabled is not None:
            self.ssl_on_connect_enabled = ssl_on_connect_enabled
        if ssl_server_identity_check_enabled is not None:
            self.ssl_server_identity_check_enabled = ssl_server_identity_check_enabled
        if nexus_trust_store_enabled is not None:
            self.nexus_trust_store_enabled = nexus_trust_store_enabled

    @property
    def enabled(self):
        """Gets the enabled of this ApiEmailConfiguration.  # noqa: E501


        :return: The enabled of this ApiEmailConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ApiEmailConfiguration.


        :param enabled: The enabled of this ApiEmailConfiguration.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def host(self):
        """Gets the host of this ApiEmailConfiguration.  # noqa: E501


        :return: The host of this ApiEmailConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this ApiEmailConfiguration.


        :param host: The host of this ApiEmailConfiguration.  # noqa: E501
        :type: str
        """

        self._host = host

    @property
    def port(self):
        """Gets the port of this ApiEmailConfiguration.  # noqa: E501


        :return: The port of this ApiEmailConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this ApiEmailConfiguration.


        :param port: The port of this ApiEmailConfiguration.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and port is None:  # noqa: E501
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def username(self):
        """Gets the username of this ApiEmailConfiguration.  # noqa: E501


        :return: The username of this ApiEmailConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this ApiEmailConfiguration.


        :param username: The username of this ApiEmailConfiguration.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def password(self):
        """Gets the password of this ApiEmailConfiguration.  # noqa: E501


        :return: The password of this ApiEmailConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this ApiEmailConfiguration.


        :param password: The password of this ApiEmailConfiguration.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def from_address(self):
        """Gets the from_address of this ApiEmailConfiguration.  # noqa: E501


        :return: The from_address of this ApiEmailConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """Sets the from_address of this ApiEmailConfiguration.


        :param from_address: The from_address of this ApiEmailConfiguration.  # noqa: E501
        :type: str
        """

        self._from_address = from_address

    @property
    def subject_prefix(self):
        """Gets the subject_prefix of this ApiEmailConfiguration.  # noqa: E501

        A prefix to add to all email subjects to aid in identifying automated emails  # noqa: E501

        :return: The subject_prefix of this ApiEmailConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._subject_prefix

    @subject_prefix.setter
    def subject_prefix(self, subject_prefix):
        """Sets the subject_prefix of this ApiEmailConfiguration.

        A prefix to add to all email subjects to aid in identifying automated emails  # noqa: E501

        :param subject_prefix: The subject_prefix of this ApiEmailConfiguration.  # noqa: E501
        :type: str
        """

        self._subject_prefix = subject_prefix

    @property
    def start_tls_enabled(self):
        """Gets the start_tls_enabled of this ApiEmailConfiguration.  # noqa: E501

        Enable STARTTLS Support for Insecure Connections  # noqa: E501

        :return: The start_tls_enabled of this ApiEmailConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._start_tls_enabled

    @start_tls_enabled.setter
    def start_tls_enabled(self, start_tls_enabled):
        """Sets the start_tls_enabled of this ApiEmailConfiguration.

        Enable STARTTLS Support for Insecure Connections  # noqa: E501

        :param start_tls_enabled: The start_tls_enabled of this ApiEmailConfiguration.  # noqa: E501
        :type: bool
        """

        self._start_tls_enabled = start_tls_enabled

    @property
    def start_tls_required(self):
        """Gets the start_tls_required of this ApiEmailConfiguration.  # noqa: E501

        Require STARTTLS Support  # noqa: E501

        :return: The start_tls_required of this ApiEmailConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._start_tls_required

    @start_tls_required.setter
    def start_tls_required(self, start_tls_required):
        """Sets the start_tls_required of this ApiEmailConfiguration.

        Require STARTTLS Support  # noqa: E501

        :param start_tls_required: The start_tls_required of this ApiEmailConfiguration.  # noqa: E501
        :type: bool
        """

        self._start_tls_required = start_tls_required

    @property
    def ssl_on_connect_enabled(self):
        """Gets the ssl_on_connect_enabled of this ApiEmailConfiguration.  # noqa: E501

        Enable SSL/TLS Encryption upon Connection  # noqa: E501

        :return: The ssl_on_connect_enabled of this ApiEmailConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._ssl_on_connect_enabled

    @ssl_on_connect_enabled.setter
    def ssl_on_connect_enabled(self, ssl_on_connect_enabled):
        """Sets the ssl_on_connect_enabled of this ApiEmailConfiguration.

        Enable SSL/TLS Encryption upon Connection  # noqa: E501

        :param ssl_on_connect_enabled: The ssl_on_connect_enabled of this ApiEmailConfiguration.  # noqa: E501
        :type: bool
        """

        self._ssl_on_connect_enabled = ssl_on_connect_enabled

    @property
    def ssl_server_identity_check_enabled(self):
        """Gets the ssl_server_identity_check_enabled of this ApiEmailConfiguration.  # noqa: E501

        Verify the server certificate when using TLS or SSL  # noqa: E501

        :return: The ssl_server_identity_check_enabled of this ApiEmailConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._ssl_server_identity_check_enabled

    @ssl_server_identity_check_enabled.setter
    def ssl_server_identity_check_enabled(self, ssl_server_identity_check_enabled):
        """Sets the ssl_server_identity_check_enabled of this ApiEmailConfiguration.

        Verify the server certificate when using TLS or SSL  # noqa: E501

        :param ssl_server_identity_check_enabled: The ssl_server_identity_check_enabled of this ApiEmailConfiguration.  # noqa: E501
        :type: bool
        """

        self._ssl_server_identity_check_enabled = ssl_server_identity_check_enabled

    @property
    def nexus_trust_store_enabled(self):
        """Gets the nexus_trust_store_enabled of this ApiEmailConfiguration.  # noqa: E501

        Use the Nexus Repository Manager's certificate truststore  # noqa: E501

        :return: The nexus_trust_store_enabled of this ApiEmailConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._nexus_trust_store_enabled

    @nexus_trust_store_enabled.setter
    def nexus_trust_store_enabled(self, nexus_trust_store_enabled):
        """Sets the nexus_trust_store_enabled of this ApiEmailConfiguration.

        Use the Nexus Repository Manager's certificate truststore  # noqa: E501

        :param nexus_trust_store_enabled: The nexus_trust_store_enabled of this ApiEmailConfiguration.  # noqa: E501
        :type: bool
        """

        self._nexus_trust_store_enabled = nexus_trust_store_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiEmailConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ApiEmailConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Nexus Repository Manager REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 3.20.1-01
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from nexus_api_python_client.configuration import Configuration


class S3BlobStoreApiBucketSecurity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_key_id': 'str',
        'secret_access_key': 'str',
        'role': 'str',
        'session_token': 'str'
    }

    attribute_map = {
        'access_key_id': 'accessKeyId',
        'secret_access_key': 'secretAccessKey',
        'role': 'role',
        'session_token': 'sessionToken'
    }

    def __init__(self, access_key_id=None, secret_access_key=None, role=None, session_token=None, local_vars_configuration=None):  # noqa: E501
        """S3BlobStoreApiBucketSecurity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_key_id = None
        self._secret_access_key = None
        self._role = None
        self._session_token = None
        self.discriminator = None

        if access_key_id is not None:
            self.access_key_id = access_key_id
        if secret_access_key is not None:
            self.secret_access_key = secret_access_key
        if role is not None:
            self.role = role
        if session_token is not None:
            self.session_token = session_token

    @property
    def access_key_id(self):
        """Gets the access_key_id of this S3BlobStoreApiBucketSecurity.  # noqa: E501

        An IAM access key ID for granting access to the S3 bucket  # noqa: E501

        :return: The access_key_id of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :rtype: str
        """
        return self._access_key_id

    @access_key_id.setter
    def access_key_id(self, access_key_id):
        """Sets the access_key_id of this S3BlobStoreApiBucketSecurity.

        An IAM access key ID for granting access to the S3 bucket  # noqa: E501

        :param access_key_id: The access_key_id of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :type: str
        """

        self._access_key_id = access_key_id

    @property
    def secret_access_key(self):
        """Gets the secret_access_key of this S3BlobStoreApiBucketSecurity.  # noqa: E501

        The secret access key associated with the specified IAM access key ID  # noqa: E501

        :return: The secret_access_key of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :rtype: str
        """
        return self._secret_access_key

    @secret_access_key.setter
    def secret_access_key(self, secret_access_key):
        """Sets the secret_access_key of this S3BlobStoreApiBucketSecurity.

        The secret access key associated with the specified IAM access key ID  # noqa: E501

        :param secret_access_key: The secret_access_key of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :type: str
        """

        self._secret_access_key = secret_access_key

    @property
    def role(self):
        """Gets the role of this S3BlobStoreApiBucketSecurity.  # noqa: E501

        An IAM role to assume in order to access the S3 bucket  # noqa: E501

        :return: The role of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this S3BlobStoreApiBucketSecurity.

        An IAM role to assume in order to access the S3 bucket  # noqa: E501

        :param role: The role of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def session_token(self):
        """Gets the session_token of this S3BlobStoreApiBucketSecurity.  # noqa: E501

        An AWS STS session token associated with temporary security credentials which grant access to the S3 bucket  # noqa: E501

        :return: The session_token of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :rtype: str
        """
        return self._session_token

    @session_token.setter
    def session_token(self, session_token):
        """Sets the session_token of this S3BlobStoreApiBucketSecurity.

        An AWS STS session token associated with temporary security credentials which grant access to the S3 bucket  # noqa: E501

        :param session_token: The session_token of this S3BlobStoreApiBucketSecurity.  # noqa: E501
        :type: str
        """

        self._session_token = session_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, S3BlobStoreApiBucketSecurity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, S3BlobStoreApiBucketSecurity):
            return True

        return self.to_dict() != other.to_dict()
